@@ -1,11 +1,11 @@
 context("issue #55")
 
 test_that("character id is supported", {
-  n <- 15
-  N <- 100
+  n <- 5
+  N <- 10
   x <- data.frame(
-    id = sample(seq(n), size = N, replace = TRUE),
-    code = sample_diag(N)
+    id = rep(x = seq(n), each = N),
+    code = sample_diag(N * n)
   )
   x$id <- as.character(x$id)
   cmb <- comorbidity(x = x, id = "id", code = "code", map = "charlson_icd10_quan", assign0 = FALSE)
@@ -16,10 +16,10 @@ test_that("character id is supported", {
 test_that("character vs integer id makes no difference", {
   for (times in seq(50)) {
     n <- 5
-    N <- 50
+    N <- 10
     x <- data.frame(
-      id = sample(seq(n), size = N, replace = TRUE),
-      code = sample_diag(N)
+      id = rep(x = seq(n), each = N),
+      code = sample_diag(N * n)
     )
     cmb1 <- comorbidity(x = x, id = "id", code = "code", map = "charlson_icd10_quan", assign0 = FALSE)
     x$id <- as.character(x$id)
@@ -32,11 +32,11 @@ test_that("character vs integer id makes no difference", {
 })
 
 test_that("character id with extra columns", {
-  n <- 15
-  N <- 100
+  n <- 5
+  N <- 10
   x <- data.frame(
-    id = sample(seq(n), size = N, replace = TRUE),
-    code = sample_diag(N)
+    id = rep(x = seq(n), each = N),
+    code = sample_diag(N * n)
   )
   x$id <- as.character(x$id)
   cmb <- comorbidity(x = x, id = "id", code = "code", map = "charlson_icd10_quan", assign0 = FALSE)
